# Social Media
A list of social media accounts for the selected person/company saved in the database. This will also include accounts from a person's primary employer. If the person has no primary employer it will include social media accounts from every one of its employers.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Platform:
The account's platform. Can be one of the following: Facebook, Instagram, LinkedIn, Reddit, TikTok, Tumblr, Twitter or Xing.

### Location:
The account's location of use. Can be one of four locations: Work, Private, Home or Other. Work will be selected by default when creating a new contact.

### URL:
The social media account's url.

## Primary Functionality:
Primary social media accounts cannot be deleted unless they are the entry's last account. You need to make one of the other accounts their primary account before being able to delete it.

## Legend:
Click on the legend to filter primary social media accounts. When displaying social media accounts of a person you can also filter accounts belonging to the person's employer(s) by clicking on the legend "Company Contact".

## Search Field:
Typing in the search field allows to filter the social media accounts by their platform.
